]> sigrok.org Git - libsigrok.git/blobdiff - device.c
Doxygen: Fix a few warnings.
[libsigrok.git] / device.c
index cbb3853443041c6a4b1316e9907763d944faa8f9..5e1c8364edb22dab1ca88a775332c00726cb3033 100644 (file)
--- a/device.c
+++ b/device.c
 
 #include <stdio.h>
 #include <glib.h>
+#include "config.h" /* Needed for HAVE_LIBUSB_1_0 and others. */
 #include "libsigrok.h"
 #include "libsigrok-internal.h"
 
+/* Message logging helpers with driver-specific prefix string. */
+#define DRIVER_LOG_DOMAIN "device: "
+#define sr_log(l, s, args...) sr_log(l, DRIVER_LOG_DOMAIN s, ## args)
+#define sr_spew(s, args...) sr_spew(DRIVER_LOG_DOMAIN s, ## args)
+#define sr_dbg(s, args...) sr_dbg(DRIVER_LOG_DOMAIN s, ## args)
+#define sr_info(s, args...) sr_info(DRIVER_LOG_DOMAIN s, ## args)
+#define sr_warn(s, args...) sr_warn(DRIVER_LOG_DOMAIN s, ## args)
+#define sr_err(s, args...) sr_err(DRIVER_LOG_DOMAIN s, ## args)
+
+/**
+ * @file
+ *
+ * Device handling in libsigrok.
+ */
+
+/**
+ * @defgroup grp_devices Devices
+ *
+ * Device handling in libsigrok.
+ *
+ * @{
+ */
+
+/** @private */
 SR_PRIV struct sr_probe *sr_probe_new(int index, int type,
                gboolean enabled, const char *name)
 {
        struct sr_probe *probe;
 
        if (!(probe = g_try_malloc0(sizeof(struct sr_probe)))) {
-               sr_err("hwdriver: probe malloc failed");
+               sr_err("Probe malloc failed.");
                return NULL;
        }
 
@@ -151,46 +176,48 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
 }
 
 /**
* Determine whether the specified device has the specified capability.
  *
- * @param dev Pointer to the device instance to be checked. Must not be NULL.
+ * @param sdi Pointer to the device instance to be checked. Must not be NULL.
  *            If the device's 'driver' field is NULL (virtual device), this
  *            function will always return FALSE (virtual devices don't have
  *            a hardware capabilities list).
* @param hwcap The capability that should be checked (whether it's supported
*              by the specified device).
  *
* @return TRUE if the device has the specified capability, FALSE otherwise.
*         FALSE is also returned upon invalid input parameters or other
  *         error conditions.
  */
-SR_API gboolean sr_dev_has_hwcap(const struct sr_dev_inst *sdi, int hwcap)
+SR_API gboolean sr_dev_has_option(const struct sr_dev_inst *sdi, int key)
 {
-       const int *hwcaps;
+       const int *devopts;
        int i;
 
        if (!sdi || !sdi->driver)
                return FALSE;
 
-       if (sdi->driver->info_get(SR_DI_HWCAPS,
-                       (const void **)&hwcaps, NULL) != SR_OK)
+       if (sdi->driver->config_list(SR_CONF_DEVICE_OPTIONS,
+                       (const void **)&devopts, NULL) != SR_OK)
                return FALSE;
 
-       for (i = 0; hwcaps[i]; i++) {
-               if (hwcaps[i] == hwcap)
+       for (i = 0; devopts[i]; i++) {
+               if (devopts[i] == key)
                        return TRUE;
        }
 
        return FALSE;
 }
 
+/** @private */
 SR_PRIV struct sr_dev_inst *sr_dev_inst_new(int index, int status,
                const char *vendor, const char *model, const char *version)
 {
        struct sr_dev_inst *sdi;
 
        if (!(sdi = g_try_malloc(sizeof(struct sr_dev_inst)))) {
-               sr_err("hwdriver: %s: sdi malloc failed", __func__);
+               sr_err("Device instance malloc failed.");
                return NULL;
        }
 
@@ -207,6 +234,7 @@ SR_PRIV struct sr_dev_inst *sr_dev_inst_new(int index, int status,
        return sdi;
 }
 
+/** @private */
 SR_PRIV void sr_dev_inst_free(struct sr_dev_inst *sdi)
 {
        struct sr_probe *probe;
@@ -228,13 +256,14 @@ SR_PRIV void sr_dev_inst_free(struct sr_dev_inst *sdi)
 
 #ifdef HAVE_LIBUSB_1_0
 
+/** @private */
 SR_PRIV struct sr_usb_dev_inst *sr_usb_dev_inst_new(uint8_t bus,
                        uint8_t address, struct libusb_device_handle *hdl)
 {
        struct sr_usb_dev_inst *udi;
 
        if (!(udi = g_try_malloc(sizeof(struct sr_usb_dev_inst)))) {
-               sr_err("hwdriver: %s: udi malloc failed", __func__);
+               sr_err("USB device instance malloc failed.");
                return NULL;
        }
 
@@ -245,9 +274,9 @@ SR_PRIV struct sr_usb_dev_inst *sr_usb_dev_inst_new(uint8_t bus,
        return udi;
 }
 
+/** @private */
 SR_PRIV void sr_usb_dev_inst_free(struct sr_usb_dev_inst *usb)
 {
-       /* Avoid compiler warnings. */
        (void)usb;
 
        /* Nothing to do for this device instance type. */
@@ -255,24 +284,63 @@ SR_PRIV void sr_usb_dev_inst_free(struct sr_usb_dev_inst *usb)
 
 #endif
 
+/** @private
+ * @param pathname OS-specific serial port specification. Examples:
+ * "/dev/ttyUSB0", "/dev/ttyACM1", "/dev/tty.Modem-0", "COM1".
+ * @param serialcomm A serial communication parameters string, in the form
+ * of <speed>/<data bits><parity><stopbits>, for example "9600/8n1" or
+ * "600/7o2". This is an optional parameter; it may be filled in later.
+ * @return A pointer to a newly initialized struct sr_serial_dev_inst,
+ * or NULL on error.
+ *
+ * Both parameters are copied to newly allocated strings, and freed
+ * automatically by sr_serial_dev_inst_free().
+ */
 SR_PRIV struct sr_serial_dev_inst *sr_serial_dev_inst_new(const char *port,
-                                                         int fd)
+               const char *serialcomm)
 {
        struct sr_serial_dev_inst *serial;
 
-       if (!(serial = g_try_malloc(sizeof(struct sr_serial_dev_inst)))) {
-               sr_err("hwdriver: %s: serial malloc failed", __func__);
+       if (!port) {
+               sr_err("Serial port required.");
+               return NULL;
+       }
+
+       if (!(serial = g_try_malloc0(sizeof(struct sr_serial_dev_inst)))) {
+               sr_err("Serial device instance malloc failed.");
                return NULL;
        }
 
        serial->port = g_strdup(port);
-       serial->fd = fd;
+       if (serialcomm)
+               serial->serialcomm = g_strdup(serialcomm);
+       serial->fd = -1;
 
        return serial;
 }
 
+/** @private */
 SR_PRIV void sr_serial_dev_inst_free(struct sr_serial_dev_inst *serial)
 {
        g_free(serial->port);
+       g_free(serial->serialcomm);
+       g_free(serial);
+}
+
+SR_API GSList *sr_dev_inst_list(const struct sr_dev_driver *driver)
+{
+       if (driver && driver->dev_list)
+               return driver->dev_list();
+       else
+               return NULL;
+}
+
+SR_API int sr_dev_inst_clear(const struct sr_dev_driver *driver)
+{
+       if (driver && driver->dev_clear)
+               return driver->dev_clear();
+       else
+               return SR_OK;
 }
 
+/** @} */
@@ -151,46 +176,48 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
 
 /**
- * Determine whether the specified device has the specified capability.
+ * Determine whether the specified device instance has the specified
+ * capability.
  *
@@ -151,46 +176,48 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *            function will always return FALSE (virtual devices don't have
  *            a hardware capabilities list).
- * @param hwcap The capability that should be checked (whether it's supported
- *              by the specified device).
+ * @param key The option that should be checked for support on the
+ *            specified device.
  *
@@ -151,46 +176,48 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *
- * @return TRUE if the device has the specified capability, FALSE otherwise.
- *         FALSE is also returned upon invalid input parameters or other
+ * @return TRUE if the device has the specified option, FALSE otherwise.
+ *         FALSE is also returned on invalid input parameters or other
  *         error conditions.
  */